@@ -71,6 +71,10 @@ class AnsiblePlaybook(object):
             playbook_file,
         ]
 
+        if extra_vars_dict['strace']:
+            ansible_command.insert(0, 'strace')
+            ansible_command.insert(1, '-f')
+
         extra_vars = ''
         for k, v in extra_vars_dict.items():
             if type(v) == str:
@@ -137,12 +141,11 @@ class AnsiblePlaybook(object):
                 err = True
 
             if err or not skip_errors:
-                if result.returncode != 0:
-                    msg = 'Failed to run:\n{0}\nrun_id: {1}'.format(
-                        ' '.join(cmd_for_log), random_run_id)
-                    if err:
-                        msg = '{0}\nCheck exception log for details'.format(msg)
-
+                if err or result.returncode != 0:
+                    msg = 'Failed to run:\n{0}\nrun_id: {1}\n' \
+                          'Check exception log for details'.format(
+                            ' '.join(cmd_for_log), random_run_id
+                    )
                     LOGGER.error(msg)
 
             return err, result
@@ -190,7 +193,7 @@ class AnsiblePlaybook(object):
     def _generate_parent_play(self, dir_path, play_filename):
         playbook_path = os.path.join(dir_path, play_filename)
         tmplt_path = os.path.join(os.path.dirname(__file__), 'parent_play.tmplt')
-        parent_path = '{0}/{1}.json'.format(self._path_str, play_filename + '.parent')
+        parent_path = '{0}/{1}.yml'.format(self._path_str, play_filename + '.parent')
 
         with open(tmplt_path, "r") as tmplt_file:
             tmplt = Template(tmplt_file.read())
@@ -216,6 +219,8 @@ class AnsiblePlaybook(object):
             local_extra_vars['fork_factor'] = 50
         if 'max_timeout' not in local_extra_vars:
             local_extra_vars['max_timeout'] = 120
+        if 'strace' not in local_extra_vars:
+            local_extra_vars['strace'] = False
 
         if not self._hosts:
             local_hosts = ['localhost', '127.0.0.1']
